using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using DropdownGrid;
using GridLinkLabel;
using Syncfusion.Windows.Forms.Grid;

namespace Test_DropGrid
{
    public partial class Form1 : Form
    {
        //Color readOnlyColor = Color.FromArgb(0, 78, 152);
        DataTable dtDx;
        DataTable dtPharm;
        bool DxDropDownSelected = false;
        bool DxStartEditing = false;
        private GridDataBoundGrid gridPharm;
        
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBox1.Text))
            {
                textBox1.Text = "25300";
            }
            LoadGridDx(true);
            SetGridListControlRows(gridDx, 20);
        }

        private void btnLoad_Click(object sender, EventArgs e)
        {
            LoadGridDx(true);
        }

        #region ************** G R I D: gridDx ******************

        private void gridDx_PrepareViewStyleInfo(object sender, GridPrepareViewStyleInfoEventArgs e)
        {
            // Sets row number on row header
            if (e.ColIndex == 0 && e.RowIndex != 0)
            {
                e.Style.Enabled = true;
                e.Style.Text = string.Format("{0}", e.RowIndex);
                e.Style.Font.Bold = false;
            }

            ////Updateable cells based on permissions; 
            //if (e.RowIndex > 0)
            //{
            //    string recId = gridDx[e.RowIndex, gridDx.NameToColIndex("id")].CellValue.ToString();
            //    if (!string.IsNullOrEmpty(recId) && (recId.Length < 3 || recId.Substring(0, 3) != "-"))
            //    {
            //        //This is an existing feedback record
            //        if (!visitDxRec.update)
            //        {
            //            //User is not permitted to update feedback records
            //            e.Style.CellType = GridCellTypeName.Static;
            //            e.Style.TextColor = readOnlyColor;
            //        }
            //    }
            //}

            //Wrap text
            if (e.ColIndex == gridDx.NameToColIndex("Pharmacologic Plan"))
            {
                e.Style.WrapText = true;
                gridDx.Model.RowHeights.ResizeToFit(GridRangeInfo.Row(e.RowIndex));
            }

            //// Error notification icon in row header
            //if (e.RowIndex > 0 && e.ColIndex == 0)
            //{
            //    //Find the datarow that corresponds to this grid row (will be different if a row has been deleted)
            //    DataRow findRow = CHW0.feedback.Rows.Find(gridDx[e.RowIndex, 1].CellValue.ToString());
            //    if (findRow.RowError != null && findRow.RowError != "")
            //    {
            //        e.Style.CellTipText = findRow.RowError;
            //        e.Style.Tag = findRow.RowError;
            //    }
            //}

        }

        private void gridDx_CurrentCellActivated(object sender, EventArgs e)
        {
            //Set height of drop down
            SetGridListControlRows(gridDx, 20);
        }

        private void gridDx_CurrentCellShowedDropDown(object sender, EventArgs e)
        {
            //Remember dropdown for gridDx_CurrentCellDeactivated
            DxDropDownSelected = true;
        }

        private void gridDx_CurrentCellCloseDropDown(object sender, Syncfusion.Windows.Forms.PopupClosedEventArgs e)
        {
            GridCurrentCell cc = gridDx.CurrentCell;
            if (cc.ColIndex == gridDx.NameToColIndex("ICD10") || cc.ColIndex == gridDx.NameToColIndex("Common Diagnosis"))
            {
                //Handle icd10/diagnosis dropdown
                GridDxGetDropDown();
            }
            else if(cc.ColIndex == gridDx.NameToColIndex("Pharmacologic Plan"))
            {
                //Handle pharm drop grid
                
            }
        }

        /// <summary>
        /// Used to determine if we need to check the contents of the cell, which should only occur
        /// if the user has selected a drop down value or typed something into the field. If the user is just
        /// moving in and out of the cell, then don't activate GridDxGetDropDown method
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gridDx_CurrentCellDeactivated(object sender, GridCurrentCellDeactivatedEventArgs e)
        {
            GridCurrentCell cc = gridDx.CurrentCell;
            if (cc.ColIndex == gridDx.NameToColIndex("ICD10") || cc.ColIndex == gridDx.NameToColIndex("Common Diagnosis")
                && !string.IsNullOrEmpty(gridDx[cc.RowIndex, cc.ColIndex].CellValue.ToString()))
            {
                if (!DxDropDownSelected && DxStartEditing)
                {
                    //User has typed in a response in icd10 or Common Diagnosis
                    GridDxGetDropDown();
                    DxStartEditing = false;
                }
                else
                {
                    DxDropDownSelected = false;
                    DxStartEditing = false;
                }
            }
        }

        private void gridDx_CurrentCellKeyPress(object sender, KeyPressEventArgs e)
        {
            //User typed into field; use this when cell_deactivated event to determine if we need to do lookup
            GridCurrentCell cc = gridDx.CurrentCell;
            if ((cc.ColIndex == gridDx.NameToColIndex("ICD10")) || cc.ColIndex == gridDx.NameToColIndex("Common Diagnosis"))
                        //&& !string.IsNullOrEmpty(gridDx[cc.RowIndex, cc.ColIndex].CellValue.ToString()))
            {
                if ((e.KeyChar >= 32 && e.KeyChar <= 127) || e.KeyChar == (char)Keys.Back)
                {
                    DxStartEditing = true;
                }
            }
        }
        ///GRID BUSINESS LOGIC gridDx
        /// <summary>
        /// Load gridDx
        /// </summary>
        private void LoadGridDx(bool SetColWidths)
        {
            ////Columns:
            //  id (requierd)
            //  visitId (required)
            //  patientId (required)
            //  dxICD10Code (required)
            //  commonPhrase (from Diagnosis)
            //  Diagnosis (from Diagnosis)
            //  dxComments
            try
            {
                gridDx.Binder.SuspendBinding();
                gridDx.Model.CellModels.Add("LinkLabelCell", new LinkLabelCellModel(gridDx.Model));
                //Xray0.images.DefaultView.Sort = "imageNumber ASC";
                //gridDx.DataSource = Xray0.images;
                
                //Datasource
                LoadGridDataSource();
                gridDx.DataSource = dtDx;

                
                gridDx.AllowResizeToFit = false;
                gridDx.Model.Options.WrapCellBehavior = GridWrapCellBehavior.NextControlInForm;
                gridDx.TableStyle.Trimming = StringTrimming.EllipsisWord;
                //gridDx.Model.ColWidths[0] = 35;
                gridDx.Model.BaseStylesMap["Row Header"].StyleInfo.CellType = "Header";
                GridModelDataBinder binder = gridDx.Binder;

                // Create child grid
                gridPharm = new GridDataBoundGrid();
                gridPharm.ThemesEnabled = true;
                gridPharm.CausesValidation = false;
                
                DropDownGridCellModel aModel = new DropDownGridCellModel(gridDx.Model);
                gridDx.Model.CellModels.Add("GridPharmDropCell", aModel);
                aModel.EmbeddedGrid = gridPharm;
                gridDx.Controls.Add(gridPharm);   
                aModel.SupportsChoiceList = true;
                
                //Id
                GridBoundColumn gbc;
                gridDx.Model.HideCols["id"] = true;
                //visitId
                gridDx.Model.HideCols["visitId"] = true;
                //PatientId
                gridDx.Model.HideCols["patientId"] = true;
                //ICD10
                gbc = binder.InternalColumns["ICD10"];
                gbc.StyleInfo.CellType = "GridListControl";
                //DataTable dtICD10 = AVCBaseUtils.GetRecordsBySP("dbo.GetCommonDxListICD10");
                //dtICD10.TableName = "dtICD10";
                //dtICD10.WriteXmlSchema("dtICD10Schema.xml");
                //dtICD10.WriteXml("dtICD10.xml");
                DataTable dtICD10 = new DataTable();
                dtICD10.ReadXmlSchema(@"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtICD10Schema.xml");
                dtICD10.ReadXml(@"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtICD10.xml");
                
                dtICD10.DefaultView.Sort = "ICD10";
                gbc.StyleInfo.DataSource = dtICD10;
                gbc.StyleInfo.ValueMember = "ICD10";
                gbc.StyleInfo.DisplayMember = "ICD10";
                GridDropDownGridListControlCellRenderer gcr = (GridDropDownGridListControlCellRenderer)gridDx.CellRenderers["GridListControl"];
                gcr.ListControlPart.ShowColumnHeader = false; // to hide the header in the dropdown
                gcr.ListControlPart.ThemesEnabled = true;
                gridDx.Model.ColWidths["ICD10"] = 60;

                //Common Diagnosis - Grid dropdown
                gbc = binder.InternalColumns["Common Diagnosis"];
                gbc.StyleInfo.CellType = "GridListControl";
                //DataTable dtCommonPhrase = AVCBaseUtils.GetRecordsBySP("dbo.GetCommonDxList");
                //dtCommonPhrase.TableName = "dtCommonPhrase";
                //dtCommonPhrase.WriteXmlSchema("dtCommonPhraseSchema.xml");
                //dtCommonPhrase.WriteXml("dtCommonPhrase.xml");
                DataTable dtCommonPhrase = new DataTable();
                dtCommonPhrase.ReadXmlSchema(@"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtCommonPhraseSchema.xml");
                dtCommonPhrase.ReadXml(@"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtCommonPhrase.xml");

                dtCommonPhrase.DefaultView.Sort = "Common Diagnosis";
                gbc.StyleInfo.DataSource = dtCommonPhrase;
                gbc.StyleInfo.ValueMember = "Common Diagnosis";
                gbc.StyleInfo.DisplayMember = "Common Diagnosis";
                GridDropDownGridListControlCellRenderer gcr1 = (GridDropDownGridListControlCellRenderer)gridDx.CellRenderers["GridListControl"];
                gcr1.ListControlPart.ShowColumnHeader = false; // to hide the header in the dropdown
                gcr1.ListControlPart.ThemesEnabled = true;
                gbc.StyleInfo.DropDownStyle = GridDropDownStyle.Exclusive;
                gbc.StyleInfo.DropDownStyle = GridDropDownStyle.AutoComplete;
                gridDx.Model.ColWidths["Common Diagnosis"] = 150;
                
                //Diagnosis (Description)
                gbc = binder.InternalColumns["Description"];
                gbc.StyleInfo.CellType = "LinkLabelCell";
                gbc.StyleInfo.TextColor = Color.Blue;
                gbc.StyleInfo.Font.Underline = true;
                gbc.StyleInfo.ReadOnly = true;
                gridDx.Model.ColWidths["Description"] = 70;

                //Diagnosis (fullDescription), for information
                gbc = binder.InternalColumns["fullDescription"];
                gridDx.Model.HideCols["fullDescription"] = true;

                //Comments
                gbc = binder.InternalColumns["Comments"];
                gridDx.Model.ColWidths["Comments"] = 220;

                //Test Pharm grid in cell
                gbc = binder.InternalColumns["Pharmacologic Plan"];
                gbc.StyleInfo.CellType = "GridPharmDropCell";
                //GridCellRendererBase gcr3 = gridDx.CellRenderers["GridADropCell"];

                
                //Width
                if (SetColWidths) gridDxColWidth();

                //Total Images
                //ImagesCount();
                //SetImagesDeleteState();
                //SetAddNewImageState();
                gridDx.Binder.ResumeBinding();
                gridDx.Refresh();
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        private void gridDxColWidth()
        {
            Int32 width = gridDx.Model.ColWidths[0];
            width += gridDx.Model.ColWidths["id"];
            width += gridDx.Model.ColWidths["visitId"];
            width += gridDx.Model.ColWidths["patientId"];
            width += gridDx.Model.ColWidths["ICD10"];
            width += gridDx.Model.ColWidths["Common Diagnosis"];
            width += gridDx.Model.ColWidths["Description"];
            width += gridDx.Model.ColWidths["Comments"];
            gridDx.Refresh();
            Int32 intScrollWidth = 0;
            if (gridDx.VScroll) intScrollWidth = 15;
            gridDx.Model.ColWidths["Pharmacologic Plan"] = gridDx.Width - width - intScrollWidth - 2;
        }

        private void LoadGridDataSource()
        {
            //dtDx
            //string strSelect = "v.id, v.visitId, v.patientId, v.dxICD10Code as ICD10, d.commonPhrase as [Common Diagnosis], ";
            //strSelect += "substring(d.[value] + '             ', 0, 13) as [Description], value as [fullDescription], ";
            //strSelect += "v.dxComments as Comments, dbo.GetPharms(v.id) as [Pharmacologic Plan]";
            //string strFrom = "VisitDx v join Diagnosis d on v.dxICD10Code = d.icd10Code";
            //string strWhere = "visitId = " + textBox1.Text;
            //dtDx = AVCBaseUtils.GetDataSetTable(strSelect, strFrom, strWhere, "v.id");
            //dtDx.TableName = "dtDx";
            //dtDx.WriteXmlSchema("C:\\Documents and Settings\\Dan G\\My Documents\\Visual Studio 2005\\Projects\\Test Projects\\Test_DropGrid\\dtDxSchema.xml");
            //dtDx.WriteXml("C:\\Documents and Settings\\Dan G\\My Documents\\Visual Studio 2005\\Projects\\Test Projects\\Test_DropGrid\\dtDx.xml");
            dtDx = new DataTable();
            dtDx.ReadXmlSchema(
                @"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtDxSchema.xml");
            dtDx.ReadXml(
                @"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtDx.xml");
        }

        private void GridDxGetDropDown()
        {
            ////User has selected an item in the dropdown list; populate the entire row based on this selection
            //string strDxText;
            //string strDxTextSQL;
            //string strSelect;
            //string strWhere;
            //DataTable dtListValid;
            //GridCurrentCell cc = gridDx.CurrentCell;
            //GridComboBoxCellRenderer cr = cc.Renderer as GridComboBoxCellRenderer;
            //GridDropDownGridListControlCellRenderer cr1 = (GridDropDownGridListControlCellRenderer)gridDx.CellRenderers["GridListControl"];
            ////string strStyle = cr1.CurrentStyle.CellType.ToString();

            //if (!string.IsNullOrEmpty(gridDx[cc.RowIndex, cc.ColIndex].CellValue.ToString())
            //    || !string.IsNullOrEmpty(cr1.ControlText))
            //    {
            //    //Entry is from the dropdown list; get entry
            //    if (!string.IsNullOrEmpty(cr1.ControlText))
            //    {
            //        strDxText = cr1.ControlText;
            //    }
            //    else
            //    {
            //        strDxText = gridDx[cc.RowIndex, cc.ColIndex].CellValue.ToString();
            //    }
            //    strDxTextSQL = strDxText.Replace("'", "''");
            //    if (cc.ColIndex == gridDx.NameToColIndex("ICD10"))
            //    {
            //        ////User has selected a ICD10 Code; find Diagnosis row based on ICD10 code
            //        //strSelect = "'" + strDxTextSQL + "' as icd10Code, value as Dx, commonPhrase";
            //        //strWhere = "icd10Code = '" + strDxTextSQL + "'";
            //        //dtListValid = AVCBaseUtils.GetDataSetTable(strSelect, "Diagnosis", strWhere, null);
            //    }
            //    else
            //    {
            //        ////User has entered a Common Diagnosis; find Diagnosis row based on Common Diagnosis
            //        //strSelect = "icd10Code as icd10Code, [value] as Dx, '" + strDxTextSQL + "' as commonPhrase";
            //        //strWhere = "commonPhrase = '" + strDxTextSQL + "'";
            //        //dtListValid = AVCBaseUtils.GetDataSetTable(strSelect, "Diagnosis", strWhere, null);
            //    }
            //    if(dtListValid.Rows.Count ==1)
            //    {
            //        //1 Diagnosis found; update grid
            //        DataRow drList = dtListValid.Rows[0];
            //        gridDx.Binder.BeginEdit();
            //        //  Populate id (if doesn't exist)
            //        //  Populate visitId
            //        //  Populate patientId
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("ICD10")].CellValue = drList["ICD10Code"].ToString();
            //        if (!string.IsNullOrEmpty(drList["commonPhrase"].ToString()))
            //        {
            //            //Common Diagnosis exists; use this
            //            gridDx[cc.RowIndex, gridDx.NameToColIndex("Common Diagnosis")].CellValue = drList["commonPhrase"].ToString();
            //        }   
            //        else
            //        {
            //            //No Common Diagnosis exists; populate Common Diagnosis column with ICD10 diagnosis value
            //            gridDx[cc.RowIndex, gridDx.NameToColIndex("Common Diagnosis")].CellValue = drList["Dx"].ToString();
            //        }
            //        string desc = drList["Dx"].ToString() + "              ";
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("Description")].CellValue = desc.Substring(0,13);
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("fullDescription")].CellValue = drList["Dx"].ToString();
            //        gridDx.Binder.EndEdit();
            //    }
            //    else
            //    {
            //        //Either 0 or > 1 diagnoses found; display Diagnosis selection dialog
            //        GetDxFromLongList(dtDx, strDxText, false);
            //    }
            //}
        }

        #endregion gridDx

        /// <summary>
        /// Display Diagnosis select dialog for user to search dx's
        /// </summary>
        /// <param name="dt"></param>
        /// <param name="strDxText"></param>
        private void GetDxFromLongList(DataTable dt, string strDxText, bool createNewRow)
        {
            //string strCP;
            //GridCurrentCell cc = gridDx.CurrentCell;
            //GridComboBoxCellRenderer cr = cc.Renderer as GridComboBoxCellRenderer;
            //GridDropDownGridListControlCellRenderer gcr = (GridDropDownGridListControlCellRenderer)gridDx.CellRenderers["GridListControl"];
            //int row = cc.RowIndex;
            //int col = cc.ColIndex;

            ////Show Diagnosis dialog
            ////dlgDiagnosisSelect dlgDiagnosis1 = new dlgDiagnosisSelect();
            ////dlgDiagnosis1.strSearchArg = strDxText;
            ////if (dlgDiagnosis1.ShowDialog() == DialogResult.OK)
            //{
            //    //User selected a diagnosis
            //    //DiagnosisTreeNode myNode = (DiagnosisTreeNode)dlgDiagnosis1.trvDiagnosis.SelectedNode;
            //    if (string.IsNullOrEmpty(myNode.commonPhrase.ToString()))
            //    {
            //        //No Common Diagnosis so use Dx
            //        strCP = myNode.value.ToString();
            //    }
            //    else
            //    {
            //        strCP = myNode.commonPhrase.ToString();
            //    }
                
            //    gridDx.Binder.BeginEdit();
            //    if (createNewRow)
            //    {
            //        //Create a new row in the grid
            //        DataRow newRow = dt.NewRow();
            //        string strId = DateTime.Now.Ticks.ToString();
            //        newRow["id"] = "-" + strId.Substring(strId.Length - 7, 7) + dt.Rows.Count.ToString();
            //        newRow["Description"] = myNode.value.ToString();
            //        newRow["Common Diagnosis"] = strCP;
            //        newRow["ICD10"] = myNode.ICD10Code.ToString();
            //        dt.Rows.Add(newRow);
            //        int iRowIndex = gridDx.Binder.ListManagerPositionToRowIndex(dt.Rows.Count-1);
            //        gridDx.CurrentCell.MoveTo(iRowIndex, gridDx.NameToColIndex("Common Diagnosis"));
            //    }
            //    else
            //    {
            //        //Existing row in grid
            //        // ICD10
            //        if (cc.ColIndex == gridDx.NameToColIndex("ICD10"))
            //        {
            //            // ICD10 is the current cell, overwrite the selected item (<Find...>)
            //            gcr.ControlText = myNode.ICD10Code.ToString();
            //        }
            //        //Not the current cell, set the cell value
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("ICD10")].CellValue = myNode.ICD10Code.ToString();

            //        // CommonPhrase
            //        if (cc.ColIndex == gridDx.NameToColIndex("Common Diagnosis"))
            //        {
            //            gcr.ControlText = strCP;
            //        }
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("Common Diagnosis")].CellValue = strCP;
            //        string desc = myNode.value.ToString() + "             ";
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("Description")].CellValue = desc.Substring(0, 13);
            //        gridDx[cc.RowIndex, gridDx.NameToColIndex("fullDescription")].CellValue = myNode.value.ToString();
            //    }
            //    gridDx.Binder.EndEdit();
            //    DxDropDownSelected = false;
            //}
            //else
            //{
            //    cc.MoveTo(row, col, GridSetCurrentCellOptions.ScrollInView);
            //    if (gridDx[cc.RowIndex, cc.ColIndex].CellValue.ToString().IndexOf("< Find") > -1
            //        || gcr.ControlText.IndexOf("< Find") > -1)
            //    {
            //        gridDx[cc.RowIndex, cc.ColIndex].CellValue = "";
            //        gcr.ControlText = "";
            //    }
            //}
            //gridDx.Focus();
            //CellValueChanged(); //Enable save button
        }

        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            GetDxFromLongList(dtDx, "", true);
        }

        private void gridDx_CurrentCellActivating(object sender, GridCurrentCellActivatingEventArgs e)
        {
        }

        private void gridDx_MouseUp(object sender, MouseEventArgs e)
        {
            //GridCurrentCell cc = gridDx.CurrentCell;
            //if(cc.ColIndex == gridDx.NameToColIndex("Description") && 
            //    !string.IsNullOrEmpty(gridDx[cc.RowIndex, cc.ColIndex].CellValue.ToString()))
            //{
            //    //User clicked on the description link
            //    dlgInfo dInfo = new dlgInfo();
            //    string longestString;
            //    dInfo.Text = "Diagnosis Description";
            //    string tInfo1 = "ICD10 Code: " + gridDx[cc.RowIndex, gridDx.NameToColIndex("ICD10")].CellValue.ToString() +
            //                   "\r\n"; 
            //    string tInfo2 = "Common Phrase: " + gridDx[cc.RowIndex, gridDx.NameToColIndex("Common Diagnosis")].CellValue.ToString() + "\r\n";
            //    longestString = tInfo2;
            //    string tInfo3 = "Diagnosis Description: " + gridDx[cc.RowIndex, gridDx.NameToColIndex("fullDescription")].CellValue.ToString();
            //    if (tInfo3.Length > longestString.Length) longestString = tInfo3;
            //    dInfo.txtInfo.Text = tInfo1 + tInfo2 + tInfo3;
            //    //Determine cell location to position popup
            //    int intTop = gridDx.RangeInfoToRectangle(gridDx.CurrentCell.RangeInfo).Y;
            //    int intLeft = gridDx.RangeInfoToRectangle(gridDx.CurrentCell.RangeInfo).X;
            //    int intWidth = gridDx.RangeInfoToRectangle(gridDx.CurrentCell.RangeInfo).Width;
            //    int intHeight = gridDx.RangeInfoToRectangle(gridDx.CurrentCell.RangeInfo).Height;
            //    dInfo.controlLoc = new SizeF(Left + gridNavDx.Left + intLeft + intWidth + 4, Top + gridNavDx.Top + intTop + 31);
            //    dInfo.longestString = longestString;
            //    dInfo.ShowDialog();
                
            //}
        }

        private void gridDx_CurrentCellShowingDropDown(object sender, GridCurrentCellShowingDropDownEventArgs e)
        {
            //Populate drop down grid
            GridCurrentCell cc = gridDx.CurrentCell;
            if(cc.ColIndex == gridDx.NameToColIndex("Pharmacologic Plan"))
            {
                //Populate pharm grid
                Int32 intVisitDxId = 0;
                string strVisitDxId = gridDx[cc.RowIndex, gridDx.NameToColIndex("id")].CellValue.ToString();
                if (!string.IsNullOrEmpty(strVisitDxId))
                {
                    intVisitDxId = Convert.ToInt32(strVisitDxId);
                }
                LoadGridPharm(intVisitDxId);
            }
            GridDropDownGridListControlCellRenderer cr = gridDx.CurrentCell.Renderer as GridDropDownGridListControlCellRenderer;
            if (cr != null)
                ((GridDropDownGridListControlPart)cr.ListControlPart).DropDownRows = 25; 
        }
        
        private void LoadGridPharm(Int32 visitDxId)
        {
            //Pharms for this visitDx
            //string strSelect = "p.id, p.visitId, p.patientId, p.visitDxId, p.med as [Drug Name], p.dosage as [Dosage], ";
            //strSelect += "p.duration as [Dur], p.durationUnit as [Dur Unit], p.otherManagement as [Other Management], ";
            //strSelect += "p.originalMed as [Original Med], p.originalDur as [Original Dur]";
            //string strFrom = "VisitPharm p join Formulary f on p.med = f.drugName ";
            //string strWhere = "visitDxId = " + visitDxId;
            //dtPharm = AVCBaseUtils.GetDataSetTable(strSelect, strFrom, strWhere, "p.id");
            //dtPharm.TableName = "dtPharm";
            //dtPharm.WriteXml("C:\\Documents and Settings\\Dan G\\My Documents\\Visual Studio 2005\\Projects\\Test Projects\\Test_DropGrid\\dtPharm.xml");
            //dtPharm.WriteXmlSchema("C:\\Documents and Settings\\Dan G\\My Documents\\Visual Studio 2005\\Projects\\Test Projects\\Test_DropGrid\\dtPharmSchema.xml");
            dtPharm = new DataTable();
            dtPharm.ReadXmlSchema(
                @"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtPharmSchema.xml");
            dtPharm.ReadXml(
                @"C:\Documents and Settings\haneefm\Desktop\Test_DropGrid1\Test_DropGrid1\dtPharm.xml");

             gridPharm.DataSource = dtPharm;
            GridModelDataBinder binder = gridPharm.Binder;
            gridPharm.Binder.SuspendBinding();

            gridPharm.AllowResizeToFit = false;
            gridPharm.TableStyle.Trimming = StringTrimming.EllipsisWord;
            gridPharm.Model.BaseStylesMap["Row Header"].StyleInfo.CellType = "Header";
            GridBoundColumn gbc;

            //id
            gridPharm.Model.HideCols["id"] = true;
            //visitId
            gridPharm.Model.HideCols["visitId"] = true;
            //patientId
            gridPharm.Model.HideCols["patientId"] = true;
            //visitDxId
            gridPharm.Model.HideCols["visitDxId"] = true;
            //Drug name
            gbc = binder.InternalColumns["Drug Name"];
            gbc.StyleInfo.CellType = "GridListControl";
            //DataTable dtICD10 = AVCBaseUtils.GetRecordsBySP("dbo.GetCommonDxListICD10");
            //dtICD10.DefaultView.Sort = "Drug Name";
            //gbc.StyleInfo.DataSource = dtICD10;
            //gbc.StyleInfo.ValueMember = "ICD10";
            //gbc.StyleInfo.DisplayMember = "ICD10";
            GridDropDownGridListControlCellRenderer gcr = (GridDropDownGridListControlCellRenderer)gridDx.CellRenderers["GridListControl"];
            gcr.ListControlPart.ShowColumnHeader = false; // to hide the header in the dropdown
            gcr.ListControlPart.ThemesEnabled = true;
            gridPharm.Model.ColWidths["Drug Name"] = 120;

            //Duration (float only)
            gbc = binder.InternalColumns["Dur"];
            gridPharm.Model.ColWidths["Dur"] = 80;

            //Duration Unit
            gbc = binder.InternalColumns["Dur Unit"];
            gbc.StyleInfo.CellType = "ComboBox";
            //DataTable dtFilm = AVCBaseUtils.GetDataSetTable("value, sortOrder", "XrayFilmSize", null, null);
            ////  Add blank row 
            //DataRow newRow = dtFilm.NewRow();
            //newRow["value"] = " ";
            //newRow["sortOrder"] = "0";
            //dtFilm.Rows.Add(newRow);
            //dtFilm.DefaultView.Sort = "sortOrder";
            //gbc.StyleInfo.DataSource = dtFilm;
            //gbc.StyleInfo.ValueMember = "value";
            //gbc.StyleInfo.DisplayMember = "value";
            gridPharm.Model.ColWidths["Dur Unit"] = 70;

            //Other Management
            gbc = binder.InternalColumns["Other Management"];
            //gridPharm.Model.ColWidths["Other Management"] = 80;

            //Col widths
            Int32 width = gridPharm.Model.ColWidths[0];
            width += gridPharm.Model.ColWidths["id"];
            width += gridPharm.Model.ColWidths["visitId"];
            width += gridPharm.Model.ColWidths["patientId"];
            width += gridPharm.Model.ColWidths["Drug Name"];
            width += gridPharm.Model.ColWidths["Dur"];
            width += gridPharm.Model.ColWidths["Dur Unit"];
            gridPharm.Refresh();
            Int32 intScrollWidth = 0;
            if (gridPharm.VScroll) intScrollWidth = 15;
            gridPharm.Model.ColWidths["Other Management"] = gridPharm.Width - width - intScrollWidth - 2;

            gridPharm.Binder.ResumeBinding();
            gridPharm.Refresh();
        }

        /// <summary>
        /// Sets the number of rows to display in a grid dropdown grid cell control
        /// </summary>
        /// <param name="grid"></param>
        /// <param name="intRows"></param>
        private void SetGridListControlRows(object grid, Int32 intRows)
        {
            GridControlBase gridBase = (GridControlBase)grid;
            GridCurrentCell cc = gridBase.CurrentCell;
            GridComboBoxCellRenderer cr = cc.Renderer as GridComboBoxCellRenderer;
            //string strStyle = cc.Renderer.CurrentStyle.CellType.ToString();
            //if (gridBase != null & strStyle == "GridListControl")
            //{
            GridDropDownGridListControlCellRenderer cr1 = gridBase.CurrentCell.Renderer as GridDropDownGridListControlCellRenderer;
            if (cr1 != null)
                ((GridDropDownGridListControlPart)cr1.ListControlPart).DropDownRows = intRows;
            //}
        }

    }
}